Package 'pkgicon'

Title: A Local and Robust Way to Generate Favicons for Package Documentation Sites
Description: What the package does (one paragraph).
Authors: Hugo Gruson [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-4094-1476>)
Maintainer: Hugo Gruson <[email protected]>
License: GPL-3
Version: 0.0.0.9000
Built: 2026-05-19 07:51:03 UTC
Source: https://github.com/Bisaloo/pkgicon

Help Index


A local alternative to pkgdown::build_favicons

Description

The list of returned icons is exactly the same as pkgdown::build_favicons(), to allow this function to be used as a drop-in replacement.

Usage

build_pkgdown_favicons(pkg = ".", overwrite = FALSE)

Arguments

pkg

Path to package.

overwrite

If TRUE, re-create favicons from package logo.